@@ -2,8 +2,6 @@
 #include <vector>
 #include <cmath>
 #include <time.h>
-// [[Rcpp::depends(RcppProgress)]]
-#include <progress.hpp>
 
 
 #define CIRCLE_MASS 200.0f
@@ -2500,7 +2498,7 @@ class borderLine
 
 
 
-    void simulate(UINT nCycles = 7e3, bool showProgress = false, int maxRel = 0)
+    void simulate(UINT nCycles = 7e3, int maxRel = 0)
     {
       UINT i;
       UINT it1 = nCycles;
@@ -2509,15 +2507,9 @@ class borderLine
       point maxP;
       initPoint(&maxP);
       udt.init(rdt);
-      Progress p(it1, showProgress); // we need an instance, should be improved in next version
-      if (showProgress == true){
-        Rprintf("Starting...\n");
-      }
       for (i = 0; i < it1; i++){
         setForces1();
         solve();
-        if (Progress::check_abort() ) return;
-        if (showProgress == true) p.increment();
 
       }
       //setForces3();
@@ -2527,21 +2519,18 @@ class borderLine
       }
       dataDisplay.clear();
     }
-    void refine(bool showProgress = false){
+    void refine(){
       UINT i;
       UINT it2 = (UINT) 2e2;
-      if (showProgress == true) Rprintf("Refining...\n");
       blSettings.lrdt = rdt / 10;
       setAsStable();
       UINT np = (UINT) (1.5f * (float) startPerim);
       interpolate(np);
       blSettings.margin /= 10;
       setRadii();
-      Progress p(it2, showProgress);
       for (i = 0; i < it2; i++){
         setForces2();
         solve(true);
-        if (showProgress == true) p.increment();
       }
     }
   };
@@ -2627,14 +2616,14 @@ borderLine* readVennInfo(List x){
 
 
 // [[Rcpp::export]]
-List makeVenn(List x, int nCycl, bool showProgress){
+List makeVenn(List x, int nCycl){
   List toret = List::create(Named("def") = x["def"]);
   borderLine* line = readVennInfo(x);
   if (x.containsElementNamed("set")){  // Previous run
     string points = Rcpp::as<std::string>(x["set"]);
     line->setCoords(points);
   }
-  line->simulate((UINT) nCycl, showProgress);
+  line->simulate((UINT) nCycl);
   toret["set"] = line->saveFigure();
   if (x.containsElementNamed("reg")) toret["reg"] = x["reg"];
   if (x.containsElementNamed("orig")) toret["orig"] = x["orig"];
@@ -2642,13 +2631,13 @@ List makeVenn(List x, int nCycl, bool showProgress){
 }
 
 // [[Rcpp::export]]
-StringVector refineVenn(List x, bool showProgress = false){
+StringVector refineVenn(List x){
   borderLine* line = readVennInfo(x);
   if (x.containsElementNamed("set")){  // Previous run
     string points = Rcpp::as<std::string>(x["set"]);
     line->setCoords(points);
   }
-  line->refine(showProgress);
+  line->refine();
   StringVector result = (line->toSVG());
   return result;
 }
